@@ -32,7 +32,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#define MediaInfo_Version_GUI __T("19.04")
+#define MediaInfo_Version_GUI __T("25.09.20251007")
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -73,13 +73,13 @@ public:
 
     //Related to user preferences - Action only if Preferences are OK
     int InternetCheck       (); //Test if there is new update
-    int ExplorerShell       (); //To be availble with right clic in Explorer
+    int ExplorerShell       (); //To be available with right click in Explorer
     int ShellToolTip        (); //To be available with mouse in Explorer
 
     //Special things
-    ZenLib::Ztring &Translate (ZenLib::Ztring Name); //return in the good language, or in English if not found
+    const ZenLib::Ztring &Translate (ZenLib::Ztring Name); //return in the good language, or in English if not found
 
-    //Info abou Lists
+    //Info about Lists
     ZenLib::ZtringList FolderNames;  //List of list_t --> Foldernames
     ZenLib::ZtringList DefaultNames; //List of list_t --> Default Filenames for a kind
 
@@ -87,6 +87,20 @@ public:
     bool Donated;
     bool Donate_Display;
     bool NewVersion_Display;
+
+    //Sponsor
+    bool Sponsored;
+    ZenLib::ZtringListList  SponsorMessage;
+    ZenLib::ZtringListList  SponsorUrl;
+    ZenLib::ZtringListList  SponsorBanner;
+    ZenLib::ZtringListList  SponsorBannerClickUrl;
+
+    //Plugins
+    ZenLib::Ztring GraphPluginURL;
+    ZenLib::Ztring GraphPlugin64URL;
+    ZenLib::Ztring GraphPluginVersion;
+    ZenLib::Ztring FFmpegPluginURL;
+    ZenLib::Ztring FFmpegPluginVersion;
 };
 
 //General preference for the whole program
